@@ -17,10 +17,14 @@
 
 """Wrap units implemented in adviser."""
 
+from .mkl_threads import MKLThreadsWrap
 from .no_onservation import NoObservationWrap
 
 
 # Relative ordering of units is relevant, as the order specifies order
 # in which the asked to be registered - any dependencies between them
 # can be mentioned here.
-__all__ = ["NoObservationWrap"]
+__all__ = [
+    "MKLThreadsWrap",
+    "NoObservationWrap",
+]
